<script src='https://maps.googleapis.com/maps/api/js?v=3.exp'></script>
<div style='overflow:hidden;height:{{ map.width }}px;width:{{ map.height }}px;'>
<div id='gmap_canvas' style='{{ map.width }}px;width:{{ map.height }}px;'>
</div><style>#gmap_canvas img{max-width:none!important;background:none!important}</style></div> 
<a href='https://embedmaps.org/'>embedmaps</a> 
<script type='text/javascript' src='https://embedmaps.com/google-maps-authorization/script.js?id=39031b348e250239c4f81ee771badfb0d8508a86'></script>
<script type='text/javascript'>
function init_map(){
	var myOptions = {
					zoom:{{ map.zoom }},
					center:new google.maps.LatLng({{ map.position.latitude }},{{ map.position.longitude }}),
					mapTypeId: google.maps.MapTypeId.ROADMAP
					};
					map = new google.maps.Map(document.getElementById('gmap_canvas'), myOptions);
					marker = new google.maps.Marker(
													{
													map: map,position: new google.maps.LatLng({{ map.position.latitude }},{{ map.position.longitude }})});
													infowindow = new google.maps.InfoWindow({content:'<strong></strong><br><br>{{ map.name }}<br>'
													}
													);
					google.maps.event.addListener(marker, 'click', function(){infowindow.open(map,marker);
					});
	infowindow.open(map);
	}
google.maps.event.addDomListener(window, 'load', init_map);
</script>
