{% extends "base.html" %}
{% load staticfiles i18n bootstrap %}

{% block title %}{% trans 'Contact' %}{% endblock %}

{% block content %}
<script type="text/javascript" src="/static/ckeditor/ckeditor/ckeditor.js"></script>
<script type="text/javascript" src="/static/ckeditor/ckeditor-init.js"></script>
<style>
	#id_qcf {
		display:none;
	}
</style>
<div class="row">
	<div class="col-xs-12 col-md-offset-1 col-md-10 col-md-offset-1 text-center">
		<h1><i class="fa fa-commenting-o"></i>&nbsp;{% trans 'Contact' %}</h1>
		<div>
			<form id="contact_form" action="" method="post">{% csrf_token %}
				{{ form|bootstrap }}
				<div id="submit_form">
					<input type="submit" class="btn btn-block btn-lg btn-primary" value="{% trans 'Save' %}" />
				</div>	
			</form>
		</div>
		<a class="btn btn-default gus" style="margin-top:3em" href="javascript:history.back()"><i class="fa fa-arrow-left"></i>&nbsp;{% trans 'Back' %}</a>
	</div>
</div>
{% endblock %}