# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-10-30 10:38
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Email',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=254, verbose_name='Email')),
                ('subject', models.CharField(max_length=255, verbose_name='Subject')),
                ('content', models.TextField(verbose_name='Message')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Date posted')),
                ('request', models.TextField()),
            ],
            options={
                'ordering': ('-created',),
                'verbose_name': 'Email',
                'verbose_name_plural': 'Emails',
            },
        ),
    ]
