{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans 'Contact' %}{% endblock %}

{% block content %}
<div class="row">
	<div class="col-xs-12 col-md-offset-1 col-md-10 col-md-offset-1 text-center">
		<h1 style="padding-bottom:1em"><i class="fa fa-commenting-o"></i>&nbsp;{% trans 'Contact' %}</h1>
		<div class="jumbotron text-center">
			<p>
				{% trans "Your email has been sent, thank you. We will answer soon." %}
			</p>
			<p style="padding-top:2em">
				<a class="btn btn-default btn-lg" href="/">{% trans "Home" %}</a>
			</p>
		</div>
	</div>
</div>
{% endblock %}